==> vokoscreen_2.4.0.orig.tar.gz: vokoscreen-2.4.0/language/vokoscreen_fr_FR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr_FR" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Le périphérique est en cours d&apos;utilisation</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Envoyer la dernière vidéo</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Envoyer une ou plusieurs vidéos sélectionnées</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Envoyer</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Vous trouverez la vidéo en pièce jointe</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Sélectionnez un ou plusieurs fichiers</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Bordure</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User-defined</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Le périphérique est en cours d&apos;utilisation</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>doubleclick extended to the edge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Plein écran</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Fenêtre</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Zone</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Agrandissement</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Par défaut</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Ne pas enregistrer le curseur de la souris</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Chemin de la vidéo</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Lecteur</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Minimiser Vokoscreen quand l&apos;enregistrement commence</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Lire</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Envoyer</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Temps d&apos;enregistrement</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Taille en KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Taille d&apos;écran de l&apos;enregistrement</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Réglage des FPS</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Ouvrir le répertoire</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Compte à rebours</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Jouer la dernière vidéo</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Envoyer la vidéo</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Sélectionnez un ou plusieurs fichiers</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Images par secondes actuelles</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Page d&apos;accueil</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Support</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Développeur</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Faire un don</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Programme pour l&apos;enregistrement</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traductions</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Code source</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Afficher dans la zone de notification</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Une nouvelle version est disponible</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Sélectionner la webcam</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.5.0.orig.tar.gz: vokoscreen-2.5.0/language/vokoscreen_fr_FR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr_FR" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Le périphérique est en cours d&apos;utilisation</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Périphérique</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Utilisé par</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Show Click Settings</source>
        <translation>Afficher les réglages de clic</translation>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Envoyer la dernière vidéo</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Envoyer une ou plusieurs vidéos sélectionnées</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Envoyer</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation>Veuillez installer un lecteur vidéo</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Vous trouverez la vidéo en pièce jointe</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Sélectionnez un ou plusieurs fichiers</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>double-click to maximize</source>
        <translation>Double-cliquer pour maximiser</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Bordure</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>Afficher en plein écran</translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation>Clic droit pour le menu</translation>
    </message>
    <message>
        <source>User-defined</source>
        <translation>Défini par l&apos;utilisateur</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Le périphérique est en cours d&apos;utilisation</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Périphérique</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Utilisé par</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>double-click to maximize</source>
        <translation>Double-cliquer pour maximiser</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Plein écran</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Fenêtre</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Zone</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Agrandissement</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Par défaut</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Ne pas enregistrer le curseur de la souris</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Chemin de la vidéo</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Lecteur</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Minimiser Vokoscreen quand l&apos;enregistrement commence</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Lire</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Envoyer</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Temps d&apos;enregistrement</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Taille en KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Taille d&apos;écran de l&apos;enregistrement</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Réglage des FPS</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Ouvrir le répertoire</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Compte à rebours</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Jouer la dernière vidéo</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Envoyer la vidéo</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Sélectionnez un ou plusieurs fichiers</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Images par secondes actuelles</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Page d&apos;accueil</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Support</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Développeur</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Faire un don</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traductions</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Code source</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Afficher dans la zone de notification</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Une nouvelle version est disponible</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec vidéo</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codec audio</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Sélectionner la webcam</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>Miroir</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Écran</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>Tous les écrans</translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation>Page d&apos;accueil du développeur</translation>
    </message>
    <message>
        <source>Recorder</source>
        <translation>Enregistreur</translation>
    </message>
    <message>
        <source>Select recorder</source>
        <translation>Sélectionner l&apos;enregistreur</translation>
    </message>
    <message>
        <source>Hide window</source>
        <translation>Cacher la fenêtre</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sortir</translation>
    </message>
    <message>
        <source>Show window</source>
        <translation>Montrer la fenêtre</translation>
    </message>
    <message>
        <source>Lossless</source>
        <translation>Sans perte</translation>
    </message>
</context>
</TS>
